"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.directiveGenerator = directiveGenerator;
const devkit_1 = require("@nx/devkit");
const utils_1 = require("../utils");
const version_utils_1 = require("../utils/version-utils");
const lib_1 = require("./lib");
async function directiveGenerator(tree, schema) {
    const options = await (0, lib_1.normalizeOptions)(tree, schema);
    const { major: angularMajorVersion } = (0, version_utils_1.getInstalledAngularVersionInfo)(tree);
    (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files'), options.directory, {
        selector: options.selector,
        symbolName: options.symbolName,
        fileName: options.fileName,
        standalone: options.standalone,
        // Angular v19 or higher defaults to true, while lower versions default to false
        setStandalone: (angularMajorVersion >= 19 && !options.standalone) ||
            (angularMajorVersion < 19 && options.standalone),
        tpl: '',
    });
    if (options.skipTests) {
        const pathToSpecFile = (0, devkit_1.joinPathFragments)(options.directory, `${options.fileName}.spec.ts`);
        tree.delete(pathToSpecFile);
    }
    if (!options.skipImport && !options.standalone) {
        const modulePath = (0, utils_1.findModule)(tree, options.directory, options.module);
        (0, utils_1.addToNgModule)(tree, options.directory, modulePath, options.name, options.symbolName, options.fileName, 'declarations', true, options.export);
    }
    if (!options.skipFormat) {
        await (0, devkit_1.formatFiles)(tree);
    }
}
exports.default = directiveGenerator;
